<?php


/**
 * Class WPTelegram_Telegram_Api.
 *
 * 
 */
class WPTelegram_Telegram_Api
{

    /**
     * @var string Telegram Bot API Access Token.
     */
    protected $botToken = null;

    /**
     * WP_Error
     *
     * @var WP_Error
     */
    protected $WP_Error;

    /**
     * Instantiates a new Telegram super-class object.
     *
     *
     * @param string    $token   The Telegram Bot API Access Token.
     *
     */
    public function __construct($token = null)
    {
        $this->botToken = isset( $token ) ? $token : false;
        if ( ! $this->botToken ) {
            throw new Exception( 'Bot token is required' );
        }
    }

    /**
     * get information about a Chat
     *
     * @since  1.3.7
     */
    public function getChat( $params ){

        return $this->sendRequest( __FUNCTION__, $params );
    }

    /**
     * Returns Telegram Bot API Access Token.
     *
     * @return string
     */
    public function getBotToken()
    {
        return $this->botToken;
    }

    /**
     * Get updates using long polling
     *
     * @since  1.3.7
     */
    public function getWebhookInfo(){

        return $this->sendRequest( __FUNCTION__ );
    }

    /**
     * setWebhook
     *
     * @since  1.3.7
     */
    public function setWebhook( $params ){

        return $this->sendRequest( __FUNCTION__, $params );
    }

    /**
     * deleteWebhook
     *
     * @since  1.3.7
     */
    public function deleteWebhook(){

        return $this->sendRequest( __FUNCTION__ );
    }

    /**
     * Get updates using long polling
     *
     * @since  1.3.7
     */
    public function getUpdates( $params ){

        return $this->sendRequest( __FUNCTION__, $params );
    }

    /**
     * Send Photo
     *
     * @since  1.0.0
     */
    public function sendPhoto( $params ){

        return $this->sendRequest( __FUNCTION__, $params );
    }

    /**
     * Send Message
     *
     * @since  1.0.0
     */
    public function sendMessage( $params ){
        
        // break text after every 4096th character and preserve words
        preg_match_all( '/.{1,4095}(?:\s|$)/su', $params['text'], $matches );
        foreach ( $matches[0] as $text ) {
            $params['text'] = $text;
            $res = $this->sendRequest( __FUNCTION__, $params);
            $params['reply_to_message_id'] = null;
        }
        return $res;
    }

    /**
     * getFile
     *
     * @since  1.3.7
     */
    public function getFile( $params ){
        
        return $this->sendRequest( __FUNCTION__, $params );
    }

    /**
     * Prepare Message
     *
     * @since  1.0.0
     */
    private function sendRequest( $endpoint, $params = '' ){
        
        $url = 'https://api.telegram.org/bot'.$this->getBotToken() . '/' . $endpoint;
        $body = $params;
        $res = wp_remote_post(
            $url,
            compact( 'body' )
        );
        if ( ! is_wp_error( $res ) ) {
            $body = wp_remote_retrieve_body( $res );
            return json_decode( $body, true );
        }

        set_site_transient( 'wptelegram_http_error', $res, 45 );
        $this->Handle_WP_Error( $res );
        return false;
    }

    /**
     * Handle WP_Error of wp_remote_post()
     *
     * @since  1.3.0
     */
    private function Handle_WP_Error( $WP_Error )
    {
        $this->WP_Error = $WP_Error;
        add_filter('redirect_post_location', array( $this, 'add_admin_notice_query_var'), 99);
    }

    /**
     * Add query variable upon error
     *
     * @since  1.3.0
     */
    public function add_admin_notice_query_var( $location ) {
        remove_filter( 'redirect_post_location', array( $this, __FUNCTION__ ), 99 );
        return add_query_arg( array( 'wptelegram' => $this->WP_Error->get_error_code() ), $location );
    }
}
