<?php
$GLOBALS['wptelegram_options'] = wptelegram_get_all_options();
/**
 * Set the global options variable
 *
 * @since  1.2.0
 *
 * @return array
 */
function wptelegram_get_all_options() {
	$options = array(
		'telegram'  => get_option( 'wptelegram_telegram' ),
		'wordpress' => get_option( 'wptelegram_wordpress' ),
		'message'   => get_option( 'wptelegram_message' ),
		);
	return apply_filters( 'wptelegram_options', $options );
}
/**
 * get individual option
 *
 * @since  1.2.0
 *
 * @param	string 	$name 	     Option name
 * @param	string 	$section 	 Section name
 * @param	mixed 	$default 	 Default value to return
 *
 * @return array
 */
function wptelegram_get_option( $name, $section, $default = false ) {
	$wptg_options = $GLOBALS['wptelegram_options'];
	if ( isset( $wptg_options[ $section ][ $name ] ) ) {
		return $wptg_options[ $section ][ $name ];
	}
	return $default;
}

/**
 * Sanitize the message_template before being saved to database
 * From _sanitize_text_fields() in wp-includes/formatting.php
 *
 * @param  string $message
 * @since  1.2.0
 * @return string           Sanitized value
 */
function wptelegram_sanitize_message_template( $message, $encoding = 'json' ) {
	$filtered = wp_check_invalid_utf8( $message );
    if ( strpos($filtered, '<') !== false ) {
        $filtered = wp_pre_kses_less_than( $filtered );
        // This will strip extra whitespace for us.
        $filtered = strip_tags( $filtered, "<b><strong><i><em><a><code><pre>");
    }

    $found = false;
    while ( preg_match( '/%[a-f0-9]{2}/i', $filtered, $match ) ) {
        $filtered = str_replace( $match[0], '', $filtered );
        $found = true;
    }

    if ( $found ) {
        // Strip out the whitespace that may now exist after removing the octets.
        $filtered = trim( preg_replace( '/ +/', ' ', $filtered ) );
    }

    $filtered = apply_filters( 'wptelegram_sanitize_message_template', $filtered, $message );

	if ( '' != $filtered && 'json' == $encoding ) {
		// json_encode to avoid errors when saving multibyte emojis into database with no multibyte support
		$filtered = json_encode( $filtered );
	}
    return $filtered;
}

/**
 * Sanitize the Bot Token before being saved to database
 *
 * @param  string $bot_token
 * @since  1.2.0
 * @return string           Sanitized value
 */
function wptelegram_sanitize_bot_token( $bot_token ) {

	$san_bot_token = sanitize_text_field( $bot_token );

	if ( preg_match( '/\A\d{9}:[\w-]{35}\Z/', $san_bot_token ) ) {
        return $san_bot_token;
    }
    else{
    	$type = 'error';
        $message = __( 'Invalid Bot Token', 'wptelegram' );

	    add_settings_error(
	        'wptelegram',
	        esc_attr( 'settings_updated' ),
	        $message,
	        $type
	    );
    }
    return '';
}

/**
 * Sanitize the Bot Token before being saved to database
 *
 * @param  string $chat_ids
 * @since  1.2.0
 * @return string           Sanitized value
 */
function wptelegram_sanitize_chat_ids( $chat_ids ) {
	$filtered = sanitize_text_field( $chat_ids );
	$filtered = trim( $filtered, " \t\n\r\0\x0B," );
	return str_replace( ' ', '', $filtered );
}

/**
 * Sanitize the input arrays
 *
 * @param  array $array
 * @since  1.2.0
 * @return array           with Sanitized keys and values
 */
function wptelegram_sanitize_array( $array ) {
	$filtered = array();
	foreach ( $array as $key => $value ) {
		$filtered[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
	}
	return $filtered;
}